\name{snow}
\title{Starting and Stopping SNOW Clusters}
\alias{getMPIcluster}
\alias{makeMPIcluster}
\alias{runMPIslave}
\alias{makePVMcluster}
\alias{makeSOCKcluster}
\alias{makeCluster}
\alias{stopCluster}
\alias{setDefaultClusterOptions}
\alias{addClusterOptions}
\alias{getClusterOption}
\usage{
# Creating and stopping clusters
getMPIcluster()
makeMPIcluster(count, ..., options = defaultClusterOptions)
makePVMcluster(count, ..., options = defaultClusterOptions)
makeSOCKcluster(names, ..., options = defaultClusterOptions)
makeCluster(n, type = getClusterOption("type"), ...)
stopCluster(cl)

# Cluster options
setDefaultClusterOptions(port = 600011, master =  Sys.info()["nodename"],
                         homogeneous=TRUE, type="SOCK",
                         outfile = "/dev/null", rhome = Sys.getenv("R_HOME"),
                         user = Sys.info()["user"], rshcmd = "ssh",
                         rlibs = Sys.getenv("R_LIBS"),
                         scriptdir = .path.package("snow"),
                         rprog = file.path(rhome, "bin", "R"))
addClusterOptions(options, ...)
getClusterOption(name, options = defaultClusterOptions)
}
\arguments{
  \item{count}{number of nodes to create}
  \item{names}{character vector of node names}
  \item{options}{cluster options object}
  \item{cl}{cluster object}
}
\description{
  Support for simple parallel computing experiments.
}
\details{
  See writeup in \url{http://www.stat.uiowa.edu/~luke/R/cluster/cluster.html}
}
\examples{
  \dontrun{
cl <- makeSOCKcluster(c("localhost","localhost"))
clusterApply(cl, 1:2, get("+"), 3)
  }
}
\keyword{internal}
\author{Luke Tierney}
